@@ -1,8 +1,7 @@
-from Products.CMFCore.utils import getToolByName
+# -*- coding: utf-8 -*-
 
 from Products.Five.browser import BrowserView
 
-
 class SearchEventsView(BrowserView):
 
     def __init__(self, context, request):
